# VL Anwendungsorientierte Analyseverfahren, Institut für Publizistik, Uni Mainz
# 2024-07-03

## Pakete und Daten laden

library(report)
library(tidyverse)
theme_set(theme_minimal())

autylewis2004 <- haven::read_sav("data/Auty_Lewis_2004.sav")
autylewis2004

## Deskriptive Statistiken

autylewis2004 |>
  group_by(pepsi_placement) |>
  count(pepsi_chosen)

autylewis2004 |>
  group_by(pepsi_placement) |>
  summarise(n = n(), m = mean(pepsi_chosen))

## Chi-Quadrat Test

table(autylewis2004$pepsi_placement, autylewis2004$pepsi_chosen) |>
  chisq.test(correct = FALSE) |>
  report::report_table()

## Bivariate Korrelation

cor.test(autylewis2004$pepsi_placement, autylewis2004$pepsi_chosen) |>
  report::report_table()

## t-Test

t.test(pepsi_chosen ~ pepsi_placement, data = autylewis2004, var.equal = TRUE) |>
  report::report_table()

##  Varianzanalyse (ANOVA)

aov(pepsi_chosen ~ pepsi_placement, data = autylewis2004) |>
  report::report_table()

## GLM: Lineare Regression

lm(pepsi_chosen ~ pepsi_placement, data = autylewis2004) |>
  report::report_table()

## GLM: Logistische Regression

glm(pepsi_chosen ~ pepsi_placement, data = autylewis2004, family = "binomial") |>
  report::report_table(exponentiate = T, include_effectsize = F)

