# VL Anwendungsorientierte Analyseverfahren, Institut für Publizistik, Uni Mainz
# 2024-07-03

## Pakete und Daten laden

library(marginaleffects)
library(report)
library(tidyverse)
theme_set(theme_minimal())

festl13 <- haven::read_sav("data/Festl13.sav") |>
  mutate(gender = as_factor(gender)) |>
  haven::zap_labels()

festl13

## Deskriptivstatistik

festl13 |>
  select(cbvictim_gen) |>
  report::report_table()

## Nullmodell

m0 <- glm(cbvictim_gen ~ 1, data = festl13, family = binomial)
report::report_table(m0)

plogis(-2.14)
round(plogis(-2.14), 2)

## Bivariate logistische Regression

m1_gender <- glm(cbvictim_gen ~ gender, festl13, family = binomial(link = "logit"))
report::report_table(m1_gender)

marginaleffects::avg_comparisons(m1_gender) |>
  as_tibble()

preds_gender <- marginaleffects::avg_predictions(m1_gender, variables = "gender") |>
  as_tibble()
preds_gender

preds_gender |>
  ggplot(aes(x = gender, y = estimate, ymin = conf.low, ymax = conf.high)) +
  geom_pointrange() +
  labs(y = "Predicted Probability of Cybervictimization", x = "Gender")

## Multiple logistische Regression

m2_gender_internet <- glm(cbvictim_gen ~ gender + internetuse, data = festl13, family = binomial)
report_table(m2_gender_internet)

marginaleffects::avg_comparisons(m2_gender_internet) |>
  as_tibble()

preds_internet <- marginaleffects::avg_predictions(m2_gender_internet, variables = c("internetuse")) |>
  as_tibble()
preds_internet

preds_internet |>
  ggplot(aes(
    x = internetuse, y = estimate, ymin = conf.low, ymax = conf.high
  )) +
  geom_line() +
  geom_ribbon(alpha = .1) +
  labs(
    x = "Internet use (hours/day)",
    y = "Predicted probability of Cybervictimization",
  )

