# VL Anwendungsorientierte Analyseverfahren, Institut für Publizistik, Uni Mainz
# 2024-07-03

## Pakete und Daten laden

library(marginaleffects)
library(report)
library(tidyverse)
theme_set(theme_minimal())

kuempel19 <- haven::read_sav("data/Kuempel_2019.sav") |>
  select(
    modus = Kurationsmodus_SNS,
    rw = Rezeptionswahrscheinlichkeit
  ) |>
  mutate(
    modus = as_factor(modus) |> relevel("Chronik"), # Faktor mit Referenz Chronik
    modus_tag = ifelse(modus == "Tag", 1, 0), # Dummy-Variable
    rw = as.numeric(rw) # Numerische Variable
  ) |>
  haven::zap_labels()

kuempel19

## Deskriptivstatistik

kuempel19 |>
  select(rw) |>
  report::report_table()

kuempel19 |>
  ggplot(aes(x = rw)) +
  geom_histogram()

kuempel19 |>
  group_by(modus) |>
  summarise(
    n = n(),
    M = mean(rw, na.rm = TRUE),
    SD = sd(rw, na.rm = TRUE)
  )

## Zwei Gruppen vergleichen

m1_tag <- lm(rw ~ modus_tag, data = kuempel19)
report::report_table(m1_tag)

## Mehr als zwei Gruppen vergleichen

m2_modus <- lm(rw ~ modus, kuempel19)
report::report_table(m2_modus)

## Referenzkategorie ändern

kuempel19 <- kuempel19 |>
  mutate(modus_dm = relevel(modus, "DM"))

m2_modus_dm <- lm(rw ~ modus_dm, kuempel19)
report::report_table(m2_modus_dm)

## Post-hoc Tests

marginaleffects::avg_comparisons(m2_modus,
  variables = list(modus = "pairwise"),
  p_adjust = "bonferroni"
)

