# VL Anwendungsorientierte Analyseverfahren, Institut für Publizistik, Uni Mainz
# 2024-07-03

## Pakete und Daten laden

library(marginaleffects)
library(report)
library(tidyverse)
theme_set(theme_minimal())

vanerkel21 <- haven::read_sav("data/Vanerkel_Vanaelst_2021.sav") |>
  mutate(
    Education = as_factor(Education),
    Gender = as_factor(Gender)
  ) |>
  haven::zap_labels()

vanerkel21

## Regressionsmodell

m1 <- lm(PK ~ Gender + Age + Education + Political_interest, data = vanerkel21)
report::report_table(m1)

## Modellvorhersagen mit kategoriellem Prädiktor

preds_gender <- marginaleffects::avg_predictions(m1, variables = "Gender") |>
  as_tibble()
preds_gender

preds_gender |>
  ggplot(aes(x = Gender, y = estimate, ymin = conf.low, ymax = conf.high)) +
  geom_pointrange() +
  labs(x = "Gender", y = "Predicted political knowledge")

## Modellvorhersagen mit mehreren kategoriellen Prädiktoren

preds_gender_edu <- marginaleffects::avg_predictions(m1, variables = c("Gender", "Education")) |>
  as_tibble()
preds_gender_edu

preds_gender_edu |>
  ggplot(aes(
    x = Gender, y = estimate, ymin = conf.low, ymax = conf.high,
    group = Education, color = Education
  )) +
  geom_pointrange(position = position_dodge(.5)) +
  labs(x = "Gender", y = "Predicted political knowledge")

## Modellvorhersagen mit metrischem Prädiktor

preds_age <- marginaleffects::avg_predictions(m1, variables = "Age") |>
  as_tibble()
preds_age

fivenum(vanerkel21$Age)

marginaleffects::avg_predictions(m1, variables = list("Age" = "threenum")) |>
  as_tibble()

marginaleffects::avg_predictions(m1, variables = list("Age" = c(18, 40, 65))) |>
  as_tibble()

preds_age |>
  ggplot(aes(
    x = Age, y = estimate, ymin = conf.low, ymax = conf.high
  )) +
  geom_ribbon(alpha = .1) +
  geom_line() +
  labs(x = "Age", y = "Predicted political knowledge")

## Modellvorhersagen mit kategoriellen und metrischen Prädiktoren

preds_age_gender <- marginaleffects::avg_predictions(m1, variables = c("Age", "Gender")) |>
  as_tibble()
preds_age_gender

preds_age_gender |>
  ggplot(aes(
    x = Age, y = estimate, ymin = conf.low, ymax = conf.high,
    group = Gender, fill = Gender, color = Gender
  )) +
  geom_ribbon(alpha = .1, color = NA) +
  geom_line() +
  labs(x = "Age", y = "Predicted political knowledge")

