# VL Anwendungsorientierte Analyseverfahren, Institut für Publizistik, Uni Mainz
# 2024-07-03

## Pakete und Daten laden

library(lme4)
library(performance)
library(marginaleffects)
library(report)
library(tidyverse)
theme_set(theme_minimal())

faehnrich19 <- haven::read_sav("data/Faehnrich_2020.sav") |>
  haven::zap_labels()

faehnrich19

## Deskriptivstatistik

count(faehnrich19, uni)

faehnrich19 |>
  select(comments_count) |>
  report::report_sample()

faehnrich19 |>
  ggplot(aes(x = comments_count)) +
  geom_histogram()

## Nullmodell und ICC

m0 <- lmer(comments_count ~ 1 + (1 | uni), data = faehnrich19)
report_table(m0)

16.71^2 / (16.71^2 + 33.32^2)

performance::icc(m0)

preds_uni <- marginaleffects::avg_predictions(m0, variables = "uni") |>
  as_tibble()
preds_uni

## Modell mit Varying Intercepts 

m1_research <- lmer(comments_count ~ 1 + topic_research + (1 | uni), data = faehnrich19)
report::report_table(m1_research)

preds_uni <- avg_predictions(m1_research, variables = c("topic_research", "uni")) |>
  as_tibble()
preds_uni

preds_uni |>
  ggplot(aes(x = factor(topic_research), y = estimate, color = uni, group = uni)) +
  geom_line(show.legend = FALSE) +
  geom_point(show.legend = FALSE) +
  labs(x = "Topic Research", y = "Predicted comments")

## Modell mit Varying Intercepts und Slopes

m2_research_vs <- lmer(comments_count ~ 1 + topic_research + (1 + topic_research | uni), data = faehnrich19)
report::report_table(m2_research_vs)
summary(m2_research_vs)

anova(m1_research, m2_research_vs)

marginaleffects::avg_slopes(m2_research_vs, by = "uni") |>
  as_tibble()

preds_uni_vs <- avg_predictions(m2_research_vs, variables = c("topic_research", "uni")) |>
  as_tibble()
preds_uni_vs

preds_uni_vs |>
  ggplot(aes(x = factor(topic_research), y = estimate, color = uni, group = uni)) +
  geom_line(show.legend = FALSE) +
  geom_point(show.legend = FALSE) +
  labs(x = "Topic Research", y = "Predicted comments")

## Modell mit Level-2-Prädiktor

m3_research_fans <- lmer(comments_count ~ 1 + topic_research + uni_fans + (1 + topic_research | uni), data = faehnrich19)
report::report_table(m3_research_fans)

