# VL Anwendungsorientierte Analyseverfahren, Institut für Publizistik, Uni Mainz
# 2024-07-03

## Pakete und Daten laden

library(report)
library(tidyverse)
theme_set(theme_minimal())

vanerkel21 <- haven::read_sav("data/Vanerkel_Vanaelst_2021.sav") |>
  mutate(
    Education = as_factor(Education),
    Gender = as_factor(Gender)
  ) |>
  haven::zap_labels()

vanerkel21

## Deskriptive Statistik

vanerkel21 |>
  select(PK) |>
  report::report_table()

vanerkel21 |>
  ggplot(aes(x = PK)) +
  geom_histogram()

## Modell 1: Nur Soziodemographie

m1_socdem <- lm(PK ~ Gender + Age + Education, data = vanerkel21)
report::report_table(m1_socdem)

## Modell 2: plus Mediennutzung

m2_media <- lm(PK ~ TV + Newspaper + Websites + Facebook + Twitter +
  Gender + Age + Education, data = vanerkel21)
report::report_table(m2_media)

## Modellvergleich

anova(m1_socdem, m2_media)

