# VL Anwendungsorientierte Analyseverfahren, Institut für Publizistik, Uni Mainz
# 2024-07-03

## Pakete und Daten laden

library(report)
library(tidyverse)
theme_set(theme_minimal())

johannes22 <- haven::read_sav("data/Johannes_2022.sav") |>
  haven::zap_labels()
johannes22

## Deskriptivstatistik

johannes22 |>
  select(music_time) |>
  report::report_table()

johannes22 |>
  ggplot(aes(x = music_time)) +
  geom_histogram()

## Scatterplot mit Regressionsgerade

johannes22 |>
  ggplot(aes(x = age, y = music_time)) +
  geom_point() +
  geom_smooth(method = "lm")

## Bivariate Regression

m1_age <- lm(music_time ~ age, data = johannes22)
report::report_table(m1_age)

## Variablen transformieren

johannes22 <- johannes22 |>
  mutate(
    age18 = age - 18,
    age_centered = age - mean(age, na.rm = TRUE),
    age_zstd = scale(age),
    music_time_zstd = scale(music_time),
    music_time_m = music_time * 60
  )

## Zentrierter Prädiktor

m1_age18 <- lm(music_time ~ age18, data = johannes22)
report::report_table(m1_age18)

## Mittelwertzentrierter Prädiktor

m1_age_c <- lm(music_time ~ age_centered, data = johannes22)
report::report_table(m1_age_c)

## Transformiertes Outcome

m1_minutes <- lm(music_time_m ~ age_centered, data = johannes22)
report::report_table(m1_minutes)

## Standardisierte Variablen

m1_zstd <- lm(music_time_zstd ~ age_zstd, data = johannes22)
report::report_table(m1_zstd)

